@@ -3,6 +3,7 @@ import async_timeout
 import requests
 import tarfile
 import os
+import glob
 from otter_service import access_sops_keys
 import shutil
 
@@ -36,6 +37,11 @@ def download_autograder_materials(url, save_path=None):
     os.remove(download_path)
     return storage_path
 
+def remove_notebook():
+    files = glob.glob('/tmp/*')
+    for f in files:
+        if not os.path.isdir(f):
+            os.remove(f)
 
 async def grade_assignment(submission, sec='3', assignment='lab01', solutions_path=None, sops_path=None, secrets_file=None, save_path=None):
     """
@@ -73,17 +79,19 @@ async def grade_assignment(submission, sec='3', assignment='lab01', solutions_pa
                                          assign_type=assign_type,
                                          sec=sec,
                                          assignment=assignment)
-        # command = [
-        #     'otter', 'grade',
-        #     '-a', zip_path, 
-        #     '-p', submission
-        # ]
+        
         command = [
-            'otter', 'run',
-            '-a',
-            zip_path,
-            submission
+            'otter', 'grade',
+            '-a', zip_path, 
+            '-p', "/tmp/",
+            "--debug"
         ]
+        # command = [
+        #     'otter', 'run',
+        #     '-a',
+        #     zip_path,
+        #     submission
+        # ]
         process = await asyncio.create_subprocess_exec(
             *command,
             stdin=asyncio.subprocess.PIPE,
@@ -101,19 +109,23 @@ async def grade_assignment(submission, sec='3', assignment='lab01', solutions_pa
             if 'Killed' in line:
                 # Our container was killed, so let's just skip this one
                 raise Exception(f"Container was killed -- nothing will work: {submission}")
-        grade = stdout.decode("utf-8").strip()
-        if grade is None or grade == '':
-            cmd = ' '.join(command)
-            raise Exception(f"Unable to determine grade coming from otter on: {submission} using this commnad: {cmd}")
-        # lines = stdout.decode("utf-8").strip().split("\n")
-        # grade = None
-        # for line in lines:
-        #     if "Total Score" in line:
-        #         grade = line.split(" ")[5][1:-2]
-        # if grade is None:
-        #     raise Exception(f"Unable to determine grade coming from otter on: {submission}")
-        return float(grade)
+        # grade = stdout.decode("utf-8").strip()
+        # if grade is None or grade == '':
+        #     cmd = ' '.join(command)
+        #     raise Exception(f"Unable to determine grade coming from otter on: {submission} using this commnad: {cmd}")
+        # This is all needed for otter 3.3.0 using --debug flag to pull the grade; otter 4.0 will be simpler
+        lines = stdout.decode("utf-8").strip().split("\n")
+        grade = None
+        for line in lines:
+            if "Total Score" in line:
+                grade = line.split(" ")[5][1:-2]
+        if grade is None:
+            raise Exception(f"Unable to determine grade coming from otter on: {submission}")
+        
+        return float(grade) / 100.0
     except asyncio.TimeoutError:
         raise Exception(f'Grading timed out for {submission}')
     except Exception as e:
         raise e
+    finally:
+        remove_notebook()
